From 27aedd08296fe880bc2f2c74f9ff68713ce14245 Mon Sep 17 00:00:00 2001
From: Aditya Vidyadhar Kamath <Aditya.Kamath1@ibm.com>
Date: Wed, 29 Mar 2023 05:18:45 -0500
Subject: [PATCH] Modify align-c/align-c++ test case for AIX

On AIX, the debugger cannot access global variables before they
they are used in any function. Hence we add this small change so
that we can test the same in AIX.
---
 gdb/testsuite/gdb.base/align.exp.tcl | 5 +++++
 1 file changed, 5 insertions(+)

diff --git a/gdb/testsuite/gdb.base/align.exp.tcl b/gdb/testsuite/gdb.base/align.exp.tcl
index 6a75a14d887..18a370df72d 100644
--- a/gdb/testsuite/gdb.base/align.exp.tcl
+++ b/gdb/testsuite/gdb.base/align.exp.tcl
@@ -129,6 +129,11 @@ proc run_alignment_test { lang } {
     if { "$lang" == "c++" } {
 	lappend flags "additional_flags=-std=c++11"
     }
+    if { [istarget *-*-aix*] } {
+        # Disable linker garbage collection to avoid optimizing
+        # out global variables unused in the test source code.
+        lappend flags "ldflags=-Wl,-ua_char_x_char"
+    }
     standard_testfile $filename
     if {[prepare_for_testing "failed to prepare" "$testfile" $srcfile $flags]} {
 	return -1
-- 
2.38.3

